pub struct GlobalCleanConfig {
pub max_src_age: Option<String>,
pub max_crate_age: Option<String>,
pub max_index_age: Option<String>,
pub max_git_co_age: Option<String>,
pub max_git_db_age: Option<String>,
}Expand description
Cache cleaning settings from the cache.global-clean config table.
NOTE: Not all of these options may get stabilized. Some of them are very low-level details, and may not be something typical users need.
If any of these options are None, the built-in default is used.
Fields
max_src_age: Option<String>Anything older than this duration will be deleted in the source cache.
max_crate_age: Option<String>Anything older than this duration will be deleted in the compressed crate cache.
max_index_age: Option<String>Any index older than this duration will be deleted from the index cache.
max_git_co_age: Option<String>Any git checkout older than this duration will be deleted from the checkout cache.
max_git_db_age: Option<String>Any git clone older than this duration will be deleted from the git cache.